@@ -59,17 +59,21 @@
 /**                                 to     05 may 2006     **/
 /**                # Version 5.0  : from : 30 nov 2006     **/
 /**                                 to     30 nov 2006     **/
+/**                # Version 5.1  : from : 08 jan 2008     **/
+/**                                 to     08 jan 2008     **/
 /**                                                        **/
 /************************************************************/
 
+#define BGRAPH_H
+
 /*
 **  The type and structure definitions.
 */
 
 /*+ Graph option flags. +*/
 
-#define BGRAPHFREEFRON              (GRAPHBITSNOTUSED) /* Free part array               */
-#define BGRAPHFREEPART              (GRAPHBITSNOTUSED << 1) /* Free frontier array      */
+#define BGRAPHFREEFRON              (GRAPHBITSNOTUSED) /* Free frontier array           */
+#define BGRAPHFREEPART              (GRAPHBITSNOTUSED << 1) /* Free part array          */
 #define BGRAPHFREEVEEX              (GRAPHBITSNOTUSED << 2) /* Free external gain array */
 
 /*+ The bipartition graph structure. +*/
