@@ -1,4 +1,4 @@
-/* Copyright 2004,2007-2009 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007-2010 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -50,7 +50,7 @@
 /**                # Version 2.0  : from : 13 jun 2005     **/
 /**                                 to   : 01 jul 2008     **/
 /**                # Version 5.1  : from : 09 nov 2008     **/
-/**                                 to   : 15 apr 2010     **/
+/**                                 to   : 02 sep 2010     **/
 /**                                                        **/
 /************************************************************/
 
@@ -120,20 +120,24 @@
 #define INT                         int32_t
 #define UINT                        u_int32_t
 #define COMM_INT                    MPI_INTEGER4
+#define INTSTRING                   "%d"
 #else /* INTSIZE32 */
 #ifdef INTSIZE64
 #define INT                         int64_t
 #define UINT                        u_int64_t
-#define COMM_INT                    MPI_INTEGER8
+#define COMM_INT                    MPI_LONG_LONG
+#define INTSTRING                   "%lld"
 #else /* INTSIZE64 */
 #ifdef LONG                                       /* Better not use it */
 #define INT                         long          /* Long integer type */
 #define UINT                        unsigned long
 #define COMM_INT                    MPI_LONG
+#define INTSTRING                   "%ld"
 #else /* LONG */
 #define INT                         int           /* Default integer type */
 #define UINT                        unsigned int
 #define COMM_INT                    MPI_INT       /* Generic MPI integer type */
+#define INTSTRING                   "%d"
 #endif /* LONG      */
 #endif /* INTSIZE64 */
 #endif /* INTSIZE32 */
@@ -166,6 +170,14 @@
 #endif /* COMM_BYTE */
 #define COMM_PART                   COMM_BYTE
 
+/*
+**  Handling of flag arrays.
+*/
+
+#define flagSize(n)                 (((n) + (sizeof (int) << 3) - 1) / (sizeof (int) << 3))
+#define flagVal(a,n)                (((a)[(n) / (sizeof (int) << 3)] >> ((n) & ((sizeof (int) << 3) - 1))) & 1)
+#define flagSet(a,n)                (a)[(n) / (sizeof (int) << 3)] |= (1 << ((n) & ((sizeof (int) << 3) - 1)))
+
 /*
 **  Handling of timers.
 */
@@ -227,6 +239,8 @@ INT                         intRandVal          (INT);
 void                        intSort1asc1        (void * const, const INT);
 void                        intSort2asc1        (void * const, const INT);
 void                        intSort2asc2        (void * const, const INT);
+void                        intSort3asc1        (void * const, const INT);
+void                        intSort3asc2        (void * const, const INT);
 INT                         intSearchDicho      (const INT * const, const INT, const INT, const INT);
 
 void                        clockInit           (Clock * const);
@@ -235,6 +249,8 @@ void                        clockStop           (Clock * const);
 double                      clockVal            (Clock * const);
 double                      clockGet            (void);
 
+void                        stringSubst         (char * const, const char * const, const char * const);
+
 /*
 **  Macro definitions.
 */
@@ -252,12 +268,15 @@ double                      clockGet            (void);
 
 #define DATASIZE(n,p,i)             ((INT) (((n) + ((p) - 1 - (i))) / (p)))
 
-#define FORTRAN(nu,nl,pl,pc)                     \
+#define FORTRAN(nu,nl,pl,pc)        FORTRAN2(FORTRAN3(nu),FORTRAN3(nl),pl,pc)
+#define FORTRAN2(nu,nl,pl,pc)                    \
 void nu pl;                                      \
 void nl pl                                       \
 { nu pc; }                                       \
-void nl##_ pl                                    \
+void FORTRAN4(nl,_) pl	                         \
 { nu pc; }                                       \
-void nl##__ pl                                   \
+void FORTRAN4(nl,__) pl                          \
 { nu pc; }                                       \
 void nu pl
+#define FORTRAN3(s)                 s
+#define FORTRAN4(p,s)               p##s
