@@ -1,4 +1,4 @@
-/* Copyright 2007 ENSEIRB, INRIA & CNRS
+/* Copyright 2007,2008,2010 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -40,6 +40,8 @@
 /**                                                        **/
 /**   DATES      : # Version 5.0  : from : 19 apr 2006     **/
 /**                                 to   : 10 sep 2007     **/
+/**                # Version 5.1  : from : 27 jun 2008     **/
+/**                                 to   : 30 jul 2010     **/
 /**                                                        **/
 /************************************************************/
 
@@ -108,7 +110,7 @@ Hdgraph * restrict const    indgrafptr)
   indgrafptr->s.proccomm   = orggrafptr->s.proccomm;
   indgrafptr->s.procglbnbr = orggrafptr->s.procglbnbr;
   indgrafptr->s.proclocnum = orggrafptr->s.proclocnum;
-  indgrafptr->s.flagval    = DGRAPHFREETABS | DGRAPHVERTGROUP | DGRAPHEDGEGROUP; /* For premature freeing on error; do not free vhndloctab as it is grouped with vertloctab */
+  indgrafptr->s.flagval    = (DGRAPHFREEALL ^ DGRAPHFREECOMM) | DGRAPHVERTGROUP | DGRAPHEDGEGROUP; /* For premature freeing on error; do not free vhndloctab as it is grouped with vertloctab */
 
   if (orggrafptr->s.veloloctax != NULL) {
     indvelolocnbr = indlistnbr;
@@ -126,8 +128,8 @@ Hdgraph * restrict const    indgrafptr)
   cheklocval =
   chekglbval = 0;
   if (memAllocGroup ((void **) (void *)           /* Allocate distributed graph private data */
-                     &indgrafptr->s.procdsptab, (size_t) ((orggrafptr->s.procglbnbr + 1) * sizeof (int)),
-                     &indgrafptr->s.proccnttab, (size_t) (orggrafptr->s.procglbnbr       * sizeof (int)),
+                     &indgrafptr->s.procdsptab, (size_t) ((orggrafptr->s.procglbnbr + 1) * sizeof (Gnum)),
+                     &indgrafptr->s.proccnttab, (size_t) (orggrafptr->s.procglbnbr       * sizeof (Gnum)),
                      &indgrafptr->s.procngbtab, (size_t) (orggrafptr->s.procglbnbr       * sizeof (int)),
                      &indgrafptr->s.procrcvtab, (size_t) (orggrafptr->s.procglbnbr       * sizeof (int)),
                      &indgrafptr->s.procsndtab, (size_t) (orggrafptr->s.procglbnbr       * sizeof (int)), NULL) == NULL) {
@@ -135,8 +137,8 @@ Hdgraph * restrict const    indgrafptr)
     cheklocval = 1;
   }
   else if (memAllocGroup ((void **) (void *)      /* Allocate distributed graph public data */
-                          &indgrafptr->s.vertloctax, (size_t) ((indlistnbr + 1) * sizeof (Gnum)), /* Compact vertex array for halo vertices */
-                          &indgrafptr->s.vendloctax, (size_t) (indlistnbr       * sizeof (Gnum)), /* Vertex end array for non-halo vertices */
+                          &indgrafptr->s.vertloctax, (size_t) ((indlistnbr + 2) * sizeof (Gnum)), /* TRICK: "+2" because never (vendloctax == (vertloctax + 1)), even for empty graphs */
+                          &indgrafptr->s.vendloctax, (size_t) (indlistnbr       * sizeof (Gnum)), /* Vertex end array for non-halo vertices                                            */
                           &indgrafptr->s.vnumloctax, (size_t) (indlistnbr       * sizeof (Gnum)),
                           &indgrafptr->s.veloloctax, (size_t) (indvelolocnbr    * sizeof (Gnum)), NULL) == NULL) {
     errorPrint ("hdgraphInduceList: out of memory (2)");
@@ -145,7 +147,7 @@ Hdgraph * restrict const    indgrafptr)
   else if (indgrafptr->s.vertloctax -= orggrafptr->s.baseval,
            indgrafptr->s.vendloctax -= orggrafptr->s.baseval,
            indgrafptr->s.vnumloctax -= orggrafptr->s.baseval,
-           indgrafptr->s.veloloctax  = ((indvelolocnbr != 0) ? indgrafptr->s.veloloctax - orggrafptr->s.baseval : NULL),
+           indgrafptr->s.veloloctax  = ((orggrafptr->s.veloloctax != NULL) ? indgrafptr->s.veloloctax - orggrafptr->s.baseval : NULL),
            memAllocGroup ((void **) (void *)
                           &indgrafptr->s.edgeloctax, (size_t) (indedgelocmax            * sizeof (Gnum)), /* Pre-allocate space for edgeloctab              */
                           &orgindxgsttax,            (size_t) (orggrafptr->s.vertgstnbr * sizeof (Gnum)), /* orgindxgsttab and orgindxhaltab are at the end */
@@ -162,8 +164,8 @@ Hdgraph * restrict const    indgrafptr)
 
     dummyval   = -1;
     chekglbval = 1;
-    if (MPI_Allgather (&dummyval, 1, MPI_INT,     /* Use proccnttab of orggraf as dummy receive array (will be regenerated) */
-                       orggrafptr->s.proccnttab, 1, MPI_INT, indgrafptr->s.proccomm) != MPI_SUCCESS)
+    if (MPI_Allgather (&dummyval, 1, GNUM_MPI,    /* Use proccnttab of orggraf as dummy receive array (will be regenerated) */
+                       orggrafptr->s.proccnttab, 1, GNUM_MPI, indgrafptr->s.proccomm) != MPI_SUCCESS)
       errorPrint ("hdgraphInduceList: communication error (1)");
 
     for (procngbnum = 1; procngbnum <= orggrafptr->s.procglbnbr; procngbnum ++) /* Rebuild proccnttab of orggraf */
@@ -171,9 +173,9 @@ Hdgraph * restrict const    indgrafptr)
   }
   else {
     indgrafptr->s.procvrttab = indgrafptr->s.procdsptab; /* Graph does not have holes */
-    indgrafptr->s.procdsptab[0] = (int) indlistnbr;
-    if (MPI_Allgather (&indgrafptr->s.procdsptab[0], 1, MPI_INT,
-                       &indgrafptr->s.proccnttab[0], 1, MPI_INT, indgrafptr->s.proccomm) != MPI_SUCCESS) {
+    indgrafptr->s.procdsptab[0] = indlistnbr;
+    if (MPI_Allgather (&indgrafptr->s.procdsptab[0], 1, GNUM_MPI,
+                       &indgrafptr->s.proccnttab[0], 1, GNUM_MPI, indgrafptr->s.proccomm) != MPI_SUCCESS) {
       errorPrint ("hdgraphInduceList: communication error (2)");
       chekglbval = 1;
     }
@@ -202,7 +204,7 @@ Hdgraph * restrict const    indgrafptr)
 
   indlisttax    = indlisttab - orggrafptr->s.baseval;
   indvertlocnnd = indlistnbr + orggrafptr->s.baseval;
-  for (indvertlocnum = orggrafptr->s.baseval, indvertglbnum = indgrafptr->s.procdsptab[indgrafptr->s.proclocnum]; /* Set adjustement for global ordering */
+  for (indvertlocnum = orggrafptr->s.baseval, indvertglbnum = indgrafptr->s.procdsptab[indgrafptr->s.proclocnum]; /* Set adjustment for global ordering */
        indvertlocnum < indvertlocnnd; indvertlocnum ++, indvertglbnum ++)
     orgindxgsttax[indlisttax[indvertlocnum]] = indvertglbnum; /* Mark selected vertices */
 
