@@ -1,4 +1,4 @@
-/* Copyright 2004,2007-2009 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007-2010 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -49,12 +49,20 @@
 /**                # Version 5.0  : from : 24 feb 2007     **/
 /**                                 to     24 jul 2007     **/
 /**                # Version 5.1  : from : 25 oct 2007     **/
-/**                                 to     27 apr 2009     **/
+/**                                 to     14 aug 2010     **/
 /**                                                        **/
 /************************************************************/
 
 #define MODULE_H
 
+/*
+** Version string.
+*/
+
+#define SCOTCH_VERSION_STRING       SCOTCH_VERSION_STRING2(SCOTCH_VERSION) "." SCOTCH_VERSION_STRING2(SCOTCH_RELEASE) "." SCOTCH_VERSION_STRING2(SCOTCH_PATCHLEVEL)
+#define SCOTCH_VERSION_STRING2(x)   SCOTCH_VERSION_STRING3(x)
+#define SCOTCH_VERSION_STRING3(x)   #x
+
 /*
 ** Collective communication handling.
 */
@@ -137,8 +145,6 @@
 
 #define commonStubDummy             _SCOTCHcommonStubDummy
 
-#define usagePrint                  _SCOTCHusagePrint
-
 #define errorPrint                  SCOTCH_errorPrint
 #define errorPrintW                 SCOTCH_errorPrintW
 #define errorProg                   SCOTCH_errorProg
@@ -163,10 +169,15 @@
 #define intSort2asc1                _SCOTCHintSort2asc1
 #define intSort2asc2                _SCOTCHintSort2asc2
 #define intSort3asc1                _SCOTCHintSort3asc1
+#define intSort3asc2                _SCOTCHintSort3asc2
 
 #define memAllocGroup               _SCOTCHmemAllocGroup
 #define memReallocGroup             _SCOTCHmemReallocGroup
 #define memOffset                   _SCOTCHmemOffset
+
+#define stringSubst                 _SCOTCHstringSubst
+
+#define usagePrint                  _SCOTCHusagePrint
 #endif /* ((! defined SCOTCH_COMMON_EXTERNAL) || (defined SCOTCH_COMMON_RENAME)) */
 
 #ifdef SCOTCH_RENAME
@@ -188,8 +199,8 @@
 #define archDomDist                 _SCOTCHarchDomDist
 #define archDomFrst                 _SCOTCHarchDomFrst
 #define archDomBipart               _SCOTCHarchDomBipart
-#define archDomMpiType              _SCOTCHarchDomMpiType
 #endif /* SCOTCH_DEBUG_ARCH2 */
+#define archDomMpiType              _SCOTCHarchDomMpiType
 #define archBuild                   _SCOTCHarchBuild
 #define archCmpltArchLoad           _SCOTCHarchCmpltArchLoad
 #define archCmpltArchSave           _SCOTCHarchCmpltArchSave
@@ -244,6 +255,7 @@
 #define archHcubDomBipart           _SCOTCHarchHcubDomBipart
 #define archHcubDomMpiType          _SCOTCHarchHcubDomMpiType
 #define archTleafArchLoad           _SCOTCHarchTleafArchLoad
+#define archTleafArchFree           _SCOTCHarchTleafArchFree
 #define archTleafArchSave           _SCOTCHarchTleafArchSave
 #define archTleafDomNum             _SCOTCHarchTleafDomNum
 #define archTleafDomTerm            _SCOTCHarchTleafDomTerm
@@ -353,6 +365,7 @@
 #define bdgraphGatherAll            _SCOTCHbdgraphGatherAll
 #define bdgraphBipartBd             _SCOTCHbdgraphBipartBd
 #define bdgraphBipartDf             _SCOTCHbdgraphBipartDf
+#define bdgraphBipartEx             _SCOTCHbdgraphBipartEx
 #define bdgraphBipartMl             _SCOTCHbdgraphBipartMl
 #define bdgraphBipartSq             _SCOTCHbdgraphBipartSq
 #define bdgraphBipartSt             _SCOTCHbdgraphBipartSt
@@ -385,6 +398,12 @@
 #define bgraphStoreSave             _SCOTCHbgraphStoreSave
 #define bgraphStoreUpdt             _SCOTCHbgraphStoreUpdt
 
+#ifdef INTSIZE64
+#define commAllgatherv              _SCOTCHcommAllgatherv
+#define commGatherv                 _SCOTCHcommGatherv
+#define commScatterv                _SCOTCHcommScatterv
+#endif /* INTSIZE64 */
+
 #define dgraphAllreduceMaxSum2      _SCOTCHdgraphAllreduceMaxSum2
 #define dgraphBuild                 _SCOTCHdgraphBuild
 #define dgraphBuild2                _SCOTCHdgraphBuild2
@@ -394,6 +413,8 @@
 #define dgraphBuildHcub             _SCOTCHdgraphBuildHcub
 #define dgraphCheck                 _SCOTCHdgraphCheck
 #define dgraphBand                  _SCOTCHdgraphBand
+#define dgraphBandColl              _SCOTCHdgraphBandColl
+#define dgraphBandPtop              _SCOTCHdgraphBandPtop
 #define dgraphCoarsen               _SCOTCHdgraphCoarsen
 #define dgraphExit                  _SCOTCHdgraphExit
 #define dgraphFold                  _SCOTCHdgraphFold
@@ -557,6 +578,9 @@
 #define kgraphmapststratab          _SCOTCHkgraphmapststratab
 #define kgraphInit                  _SCOTCHkgraphInit
 #define kgraphExit                  _SCOTCHkgraphExit
+#define kgraphCheck                 _SCOTCHkgraphCheck
+#define kgraphFrst                  _SCOTCHkgraphFrst
+#define kgraphMapMl                 _SCOTCHkgraphMapMl
 #define kgraphMapRb                 _SCOTCHkgraphMapRb
 #define kgraphMapRbMap              _SCOTCHkgraphMapRbMap
 #define kgraphMapRbPart             _SCOTCHkgraphMapRbPart
